# Bibliothèque `butinfom`

Cette bibilithèque propose des outils pour l'enseignement des mathématiques en
BUT d'informatique. Les fonctionnalités d'affichage des expressions
mathématiques sont prévues pour l'environnement Jupyter Notebook.

## Installation

### Depuis la console système

```bash
pip install butinfom
```

### Depuis une cellule de cahier Jupyter

```python
!pip install butinfom
```

*Remarque.* Cette dernière commande fonctionne notamment dans les Jupyter
Notebook de Google Colab.

## Documentation

La documentation est accessible à cette adresse
[mbensussan.yj.fr/butinfom/](https://mbensussan.yj.fr/butinfom/).